@@ -1,7 +1,7 @@
 # remove the lockfile
-local scheme=$( url_scheme $BACKUP_URL )
-local path=$( url_path $BACKUP_URL )
-local opath=$( backup_path $scheme $path )
+local scheme="$( url_scheme "$BACKUP_URL" )"
+local path="$( url_path "$BACKUP_URL" )"
+local opath="$( backup_path "$scheme" "$path" )"
 
 # if $opath is empty return silently (e.g. scheme tape)
 [ -z "$opath" ] && return 0
