@@ -10,7 +10,7 @@ Log "TAG-15-migrate: $FS_UUID_MAP"
 local sed_script=""
 local old_uuid new_uuid device
 while read old_uuid new_uuid device ; do
-    sed_script="$sed_script;/${old_uuid}/s/${old_uuid}/${new_uuid}/g"
+    sed_script+=";/${old_uuid}/s/${old_uuid}/${new_uuid}/g"
 done < <( sort -u $FS_UUID_MAP )
 # debug line:
 Debug "$sed_script"
@@ -50,7 +50,7 @@ do
             # If the symlink target contains /proc/ /sys/ /dev/ or /run/ we skip it because then
             # the symlink target is considered to not be a restored file that needs to be patched
             # cf. https://github.com/rear/rear/pull/2047#issuecomment-464846777
-            if echo $symlink_target | egrep -q '/proc/|/sys/|/dev/|/run/' ; then
+            if echo $symlink_target | grep -Eq '/proc/|/sys/|/dev/|/run/' ; then
                 LogPrint "Skip patching symlink $restored_file target $symlink_target on /proc/ /sys/ /dev/ or /run/"
                 continue
             fi
