@@ -84,18 +84,6 @@ if ! test -d "$TARGET_FS_ROOT/boot/$grub_name" ; then
     fi
 fi
 
-# Make /proc /sys /dev available in TARGET_FS_ROOT
-# so that later things work in the "chroot TARGET_FS_ROOT" environment,
-# cf. https://github.com/rear/rear/issues/1828#issuecomment-398717889
-# and do not umount them when leaving this script because
-# it is better when also after "rear recover" things still
-# work in the "chroot TARGET_FS_ROOT" environment so that
-# the user could more easily adapt things after "rear recover":
-for mount_device in proc sys dev ; do
-    umount $TARGET_FS_ROOT/$mount_device && sleep 1
-    mount --bind /$mount_device $TARGET_FS_ROOT/$mount_device
-done
-
 # Generate GRUB configuration file anew to be on the safe side (this could be even mandatory in MIGRATION_MODE):
 if ! chroot $TARGET_FS_ROOT /bin/bash --login -c "$grub_name-mkconfig -o /boot/$grub_name/grub.cfg" ; then
     LogPrintError "Failed to generate boot/$grub_name/grub.cfg in $TARGET_FS_ROOT - trying to install GRUB2 nevertheless"
