@@ -24,20 +24,11 @@ fi
 ### Prepare a disk for partitioning/general usage.
 create_disk() {
     local component disk size label junk
+    local blocksize layout dasdtype dasdcyls junk2
+
+    disk=''
     read component disk size label junk < <(grep "^disk $1 " "$LAYOUT_FILE")
-
-    ### Disks should be block devices.
-    [[ -b "$disk" ]]
-    BugIfError "Disk $disk is not a block device."
-
-    ### Find out the actual disk size.
-    local disk_size=$( get_disk_size $(get_sysfs_name "$disk") )
-
-    [[ "$disk_size" ]]
-    BugIfError "Could not determine size of disk $disk, please file a bug."
-
-    [[ $disk_size -gt 0 ]]
-    StopIfError "Disk $disk has size $disk_size, unable to continue."
+    test $disk || BugError "No 'disk $1 ' entry in $LAYOUT_FILE"
 
     cat >> "$LAYOUT_CODE" <<EOF
 
@@ -45,6 +36,9 @@ create_disk() {
 # Code handling disk '$disk'
 #
 
+### Disks should be block devices.
+test -b "$disk" || BugError "Disk '$disk' is not a block device"
+
 Log "Stop mdadm"
 if grep -q md /proc/mdstat 2>/dev/null; then
     mdadm --stop -s >&2 || echo "stop mdadm failed"
@@ -67,14 +61,15 @@ sync
 
 EOF
 
-    create_partitions "$disk" "$label"
+    # $junk can contain useful DASD-specific fields
+    create_partitions "$disk" "$label" "$junk"
 
     cat >> "$LAYOUT_CODE" <<EOF
 # Make sure device nodes are visible (eg. in RHEL4)
 my_udevtrigger
 my_udevsettle
 
-# Clean up transient partitions and resize shrinked ones
+# Clean up transient partitions and resize shrunk ones
 delete_dummy_partitions_and_resize_real_ones
 
 #
@@ -93,6 +88,11 @@ create_partitions() {
     ### List partition types/names to detect disk label type.
     local -a names=()
     local part disk size pstart name junk
+    local orig_block_size layout dasdtype dasdcyls junk2
+    if [ "$label" == dasd ]; then
+        # dasd has more fields - junk is not junk anymore
+        read orig_block_size layout dasdtype dasdcyls junk2 <<<$3
+    fi
     while read part disk size pstart name junk ; do
         names+=( $name )
         case $name in
@@ -144,7 +144,7 @@ EOF
             #if [[ "$label" == "gpt" || "$label" == "gpt_sync_mbr" || "$label" == "dasd" ]] ; then
             if [[ "$label" == "gpt" || "$label" == "gpt_sync_mbr" ]] ; then
                 device_size=$( mathlib_calculate "$device_size - 33*$block_size" )
-                # Only if resizing all partitions is explicity wanted
+                # Only if resizing all partitions is explicitly wanted
                 # resizing of arbitrary partitions may also happen via the code below
                 # in addition to layout/prepare/default/430_autoresize_all_partitions.sh
                 if is_true "$autoresize_partitions" ; then
@@ -189,7 +189,7 @@ EOF
         name=$( percent_decode "$name" )
 
         # Use the partition start value in disklayout.conf
-        # unless resizing all partitions is explicity wanted:
+        # unless resizing all partitions is explicitly wanted:
         if ! is_true "$autoresize_partitions" && test "$pstart" != "unknown" ; then
             start="$pstart"
         fi
@@ -204,7 +204,7 @@ EOF
         fi
 
         # Extended partitions run to the end of disk (we assume)
-        # only if resizing all partitions is explicity wanted:
+        # only if resizing all partitions is explicitly wanted:
         if is_true "$autoresize_partitions" ; then
             if [[ "$name" = "extended" ]] ; then
                 if [[ "$device_size" ]] ; then
@@ -227,10 +227,12 @@ EOF
             if [[ "$end" ]] ; then
                 end=$( mathlib_calculate "$end - 1" )
             fi
-            if [[ "$ARCH" == "Linux-s390" ]] ; then
-                # if dasd disk is LDL formated, then do not partition it, because it is partitioned and can take only partition
-                if [[ ! "${listDasdLdl[@]}" =~ "$device" ]] ; then
-                    echo "not LDL dasd formated disk, create a partition"
+            if [[ "$ARCH" == "Linux-s390" && "$label" == dasd ]] ; then
+                # LDL formatted disks are already partitioned and should not be partitioned with parted or fdasd , it will fail
+                if [ "$layout" == LDL ]; then
+                    Debug "$device: LDL formatted DASD, do not create a partition"
+                else
+                    Debug "$device: ${layout} formatted DASD, create a partition"
                     cat >> "$LAYOUT_CODE" <<EOF
 create_disk_partition "$device" "$name" $number $start $end
 EOF
@@ -264,7 +266,7 @@ my_udevsettle
 EOF
         fi
 
-        # Only if resizing all partitions is explicity wanted
+        # Only if resizing all partitions is explicitly wanted
         # the start of the next partition is where this one ends.
         # We can't use $end for extended partitions
         # extended partitions have a small actual size as reported by sysfs
@@ -293,7 +295,7 @@ EOF
 
         # round starting size to next multiple of 4096
         # 4096 is a good match for most device's block size
-        # only if resizing all partitions is explicity wanted:
+        # only if resizing all partitions is explicitly wanted:
         if is_true "$autoresize_partitions" ; then
             start=$(( $start + 4096 - ( $start % 4096 ) ))
         fi
@@ -320,7 +322,7 @@ EOF
         # like 'EFI System Partition' cf. https://github.com/rear/rear/issues/1563
         # so that when calling parted on command line it must be done like
         #    parted -s /dev/sdb unit MiB mkpart "'partition name'" 12 34
-        # where the outer quoting "..." is for bash which neeeds to be quoted \"...\" here
+        # where the outer quoting "..." is for bash which needs to be quoted \"...\" here
         # because there is a outermost quoting "..." of the echo command
         # and the inner quoting '...' is preserved for parted's internal parser:
         if [[ "$label" = "gpt" || "$label" == "gpt_sync_mbr" ]] && [[ "$name" != "rear-noname" ]] ; then
