@@ -61,7 +61,7 @@ extract_partitions() {
                     fi
                 done
             else
-                ### if the holders directory does not exisits 
+                ### if the holders directory does not exists 
                 ### failback to partition name guessing method.
                 ### try to find partitions like /dev/mapper/datalun1p1
                 for path in ${device}p[0-9]* ${device}[0-9]* ${device}-part* ${device}_part*; do
@@ -122,7 +122,7 @@ extract_partitions() {
     # does not work with partition types that are not in the supported list
     # cf. https://github.com/rear/rear/pull/2803#issuecomment-1124800884
     if ! [[ "$disk_label" = "msdos" || "$disk_label" = "gpt" || "$disk_label" = "gpt_sync_mbr" || "$disk_label" = "dasd" ]] ; then
-        Error "Unsupported partition table '$disk_label' (must be one of 'msdos' 'gpt' 'gpt_sync_mbr' 'dasd')"
+        Error "Unsupported partition table '$disk_label' on $device (must be one of 'msdos' 'gpt' 'gpt_sync_mbr' 'dasd')"
     fi
 
 
@@ -262,7 +262,7 @@ extract_partitions() {
             flags=""
             for flag in $flaglist ; do
                 if [[ "$flag" = boot || "$flag" = esp || "$flag" = root || "$flag" = swap || "$flag" = hidden || "$flag" = raid || "$flag" = lvm || "$flag" = lba || "$flag" = palo || "$flag" = legacy_boot || "$flag" = bios_grub || "$flag" = prep ]] ; then
-                    flags="$flags$flag,"
+                    flags+="$flag,"
                 elif [[ "$flag" = "type=06" ]] ; then
                     flags="${flags}prep,"
                 fi
@@ -293,7 +293,7 @@ extract_partitions() {
             flags=""
             for flag in $flaglist ; do
                 if [[ "$flag" = boot || "$flag" = root || "$flag" = swap || "$flag" = hidden || "$flag" = raid || "$flag" = lvm || "$flag" = lba || "$flag" = palo || "$flag" = legacy_boot || "$flag" = bios_grub || "$flag" = prep ]] ; then
-                    flags="$flags$flag,"
+                    flags+="$flag,"
                 elif [[ "$flag" = "type=06" ]] ; then
                     flags="${flags}prep,"
                 fi
@@ -371,24 +371,36 @@ extract_partitions() {
 }
 
 Log "Saving disks and their partitions"
-(   for disk in /sys/block/* ; do
+
+# Begin of group command that appends its stdout to DISKLAYOUT_FILE:
+{
+    for disk in /sys/block/* ; do
         blockd=${disk#/sys/block/}
         if [[ $blockd = hd* || $blockd = sd* || $blockd = cciss* || $blockd = vd* || $blockd = xvd* || $blockd = dasd* || $blockd = nvme* || $blockd = mmcblk* ]] ; then
 
             if [[ $blockd == dasd* && "$ARCH" == "Linux-s390" ]] ; then
                 devname=$(get_device_name $disk)
+                dasdnum=$( lsdasd | awk "\$3 == \"$blockd\" { print \$1}" )
+                dasdstatus=$( lsdasd | awk "\$3 == \"$blockd\" { print \$2}" )
+                # ECKD or FBA
+                dasdtype=$( lsdasd | awk "\$3 == \"$blockd\" { print \$5}" )
+                if [ "$dasdtype" != ECKD ] && [ "$dasdtype" != FBA ]; then
+                    LogPrint "Type $dasdtype of DASD $blockd unexpected: neither ECKD nor FBA"
+                fi
 
-                echo "# active dasd bus and channel"
-                echo "# bus-id <name device> type"
-                echo "dasd_channel $( lsdasd|grep $blockd|awk '{ print $1 " "  $2 " "  $3 " "  $4}' )"
+                echo "# every DASD bus and channel"
+                echo "# Format: dasd_channel <bus-id> <device name>"
+                echo "dasd_channel $dasdnum $blockd"
 
-                echo "# dasdfmt - disk layout is either cdl for the compatible disk layout (default) or ldl"
-                echo "#  example usage: dasdfmt -b 4096 -d cdl -y /dev/dasda"
-                layout=$(dasdview -x  /dev/$blockd|grep "^format"|awk '{print $7}')
-                blocksize=$( dasdview -i  /dev/$blockd|grep blocksize|awk '{print $6}' )
-                echo "# dasdfmt $devname"
-                echo "# dasdfmt -b <blocksize> -d <layout> -y <devname>"
-                echo "dasdfmt -b $blocksize -d $layout -y $devname"
+                # We need to print the dasd_channel line even for ignored devices,
+                # otherwise we could have naming gaps and naming would change when
+                # recreating layout.
+                # E.g. if dasda is ignored, and dasdb is not, we would create only dasdb
+                # during recreation, but it would be named dasda.
+                if [ "$dasdstatus" != active ]; then
+                    Log "Ignoring $blockd: it is not active (Status is $dasdstatus)"
+                    continue
+                fi
             fi
 
             #FIXME: exclude *rpmb (Replay Protected Memory Block) for nvme*, mmcblk* and uas
@@ -401,34 +413,66 @@ Log "Saving disks and their partitions"
             elif [[ ! ($blockd = *rpmb || $blockd = *[0-9]boot[0-9]) ]]; then # Silently skip Replay Protected Memory Blocks and others  
                 devname=$(get_device_name $disk)
                 devsize=$(get_disk_size ${disk#/sys/block/})
-                disktype=$(parted -s $devname print | grep -E "Partition Table|Disk label" | cut -d ":" -f "2" | tr -d " ")
                 # Ensure syntactically correct 'disk' entries:
                 # Each value must exist and each value must be a single non-blank word so we 'test' without quoting the value:
                 test $devname || Error "Invalid 'disk' entry (no disk device name for '$disk')"
                 test $devsize || Error "Invalid 'disk $devname' entry (no device size for '$devname')"
-                # We do not error out when there is no partition label type value because
-                # "rear recover" works in a special case without partition label type value when there is
-                # only a 'disk' entry but nothing else for this disk exists in disklayout.conf
-                # which can happen when /dev/sdX is an empty SD card slot without medium,
-                # see https://github.com/rear/rear/issues/2810
-                test $disktype || LogPrintError "No partition label type for 'disk $devname' (may cause 'rear recover' failure)"
-
-                echo "# Disk $devname"
-                echo "# Format: disk <devname> <size(bytes)> <partition label type>"
-                echo "disk $devname $devsize $disktype"
-
+                # Validation error can happen when /dev/sdX is an empty SD card slot without medium,
+                # see https://github.com/rear/rear/issues/2810 https://github.com/rear/rear/issues/2958
+                # this is normal, but such device must be skipped and not be added to the layout
+                # - it does not contain any data anyway.
+                # See https://github.com/rear/rear/pull/3047
+                if ! validation_error=$(is_disk_valid $devname) ; then
+                    LogPrintError "Ignoring $blockd: $validation_error"
+                    continue
+                fi
+                disktype=$(parted -s $devname print | grep -E "Partition Table|Disk label" | cut -d ":" -f "2" | tr -d " ")
+                test $disktype || Error "Invalid 'disk $devname' entry (no partition table type for '$devname')"
+                if [ "$disktype" != "dasd" ]; then
+                    echo "# Disk $devname"
+                    echo "# Format: disk <devname> <size(bytes)> <partition label type>"
+                    echo "disk $devname $devsize $disktype"
+                elif [[ $blockd == dasd* && "$ARCH" == "Linux-s390" ]] ; then
+                    layout=$(dasdview -x $devname |grep "^format"|awk '{print $7}')
+                    case "$layout" in
+                        (NOT)
+                            # NOT -> dasdview has printed "NOT formatted"
+                            LogPrintError "Ignoring $blockd: it is not formatted"
+                            continue
+                            ;;
+                        (LDL|CDL)
+                            ;;
+                        (*)
+                            BugError "Invalid 'disk $devname' entry (unknown DASD layout $layout)"
+                            ;;
+                    esac
+                    test $disktype || Error "No partition label type for DASD entry 'disk $devname'"
+                    blocksize=$( get_block_size "$blockd" )
+                    if ! test $blocksize ; then
+                        # fallback - ugly method
+                        blocksize=$( dasdview -i $devname |grep blocksize|awk '{print $6}' )
+                        test $blocksize || Error "Unknown block size of DASD $devname"
+                    fi
+                    dasdcyls=$( get_dasd_cylinders "$blockd" )
+                    echo "# Disk $devname"
+                    echo "# Format: disk <devname> <size(bytes)> <partition label type> <logical block size> <DASD layout> <DASD type> <size(cylinders)>"
+                    echo "disk $devname $devsize $disktype $blocksize $layout $dasdtype $dasdcyls"
+                else
+                    Error "Invalid 'disk $devname' entry (DASD partition label on non-s390 arch $ARCH)"
+                fi
                 echo "# Partitions on $devname"
                 echo "# Format: part <device> <partition size(bytes)> <partition start(bytes)> <partition type|name> <flags> /dev/<partition>"
                 extract_partitions "$devname"
             fi
         fi
     done
-) >> $DISKLAYOUT_FILE
+} 1>>$DISKLAYOUT_FILE
+# End of group command that appends its stdout to DISKLAYOUT_FILE
 
 # parted and partprobe are required in the recovery system if disklayout.conf contains at least one 'disk' or 'part' entry
 # see the create_disk and create_partitions functions in layout/prepare/GNU/Linux/100_include_partition_code.sh
 # what program calls are written to diskrestore.sh and which programs will be run during "rear recover" in any case
 # e.g. mdadm is not called in any case and sfdisk is only used in case of BLOCKCLONE_STRICT_PARTITIONING
 # cf. https://github.com/rear/rear/issues/1963
-egrep -q '^disk |^part ' $DISKLAYOUT_FILE && REQUIRED_PROGS+=( parted partprobe ) || true
+grep -Eq '^disk |^part ' $DISKLAYOUT_FILE && REQUIRED_PROGS+=( parted partprobe ) || true
 
