@@ -48,7 +48,7 @@ fi
 #   /dev/sda2 / btrfs rw,relatime,space_cache
 # The sorting relies on that mount and findmnt output the first mounted thing first
 # so that in particular what is mounted at '/' is output before other stuff.
-read_filesystems_command="$read_filesystems_command | sort -t ' ' -k 1,1 -u"
+read_filesystems_command+=" | sort -t ' ' -k 1,1 -u"
 
 # The Docker daemon mounts file systems for its Docker containers, see also
 # https://docs.docker.com/storage/storagedriver/device-mapper-driver/#configure-direct-lvm-mode-for-production
@@ -75,8 +75,8 @@ if service docker status ; then
     fi
 fi
 
-# Begin of the subshell that appends its stdout to DISKLAYOUT_FILE:
-(
+# Begin of group command that appends its stdout to DISKLAYOUT_FILE:
+{
     echo "# Filesystems (only $supported_filesystems are supported)."
     echo "# Format: fs <device> <mountpoint> <fstype> [uuid=<uuid>] [label=<label>] [<attributes>]"
     # Read the output of the read_filesystems_command:
@@ -231,8 +231,15 @@ fi
                 echo -n " uuid=$uuid label=$label"
                 ;;
             (btrfs)
+                # FIXME: Support for multi-disk BTRFS should be implemented sooner or later
+                # because it is the default layout for multi-disk Fedora Workstation installations.
+                # See: https://github.com/rear/rear/issues/2028
+                if grep -qE 'Total devices ([2-9]|[1-9][0-9]+) ' <(btrfs filesystem show "$mountpoint"); then
+                    Error "Mounpoint $mountpoint points to a BTRFS filesystem spanning multiple disk devices which is not yet supported. See: https://github.com/rear/rear/issues/2028"
+                fi
+
                 # Remember devices and mountpoints of the btrfs filesystems for the btrfs subvolume layout stuff below:
-                btrfs_devices_and_mountpoints="$btrfs_devices_and_mountpoints $device,$mountpoint"
+                btrfs_devices_and_mountpoints+=" $device,$mountpoint"
                 uuid=$( btrfs filesystem show $device | grep -o 'uuid: .*' | cut -d ':' -f 2 | tr -d '[:space:]' )
                 label=$( btrfs filesystem show $device | grep -o 'Label: [^ ]*' | cut -d ':' -f 2 | tr -d '[:space:]' )
                 test "none" = "$label" && label=
@@ -308,8 +315,8 @@ fi
             if test $( btrfs subvolume list -a $btrfs_mountpoint | wc -l ) -gt 0 ; then
                 subvolume_list=$( btrfs subvolume list -a $btrfs_mountpoint | tr -s '[:blank:]' ' ' | cut -d ' ' -f 2,9 | sed -e 's/<FS_TREE>\///' )
                 prefix=$( echo "btrfsnormalsubvol $btrfs_device $btrfs_mountpoint" | sed -e 's/\//\\\//g' )
-                # Get the IDs of the snapshot subvolumes as pattern for "egrep -v" e.g. like
-                #   egrep -v '^279 |^280 |^281 |^282 |^285 |^286 |^289 |^290 '
+                # Get the IDs of the snapshot subvolumes as pattern for "grep -Ev" e.g. like
+                #   grep -Ev '^279 |^280 |^281 |^282 |^285 |^286 |^289 |^290 '
                 # to exclude snapshot subvolume lines to get only the normal subvolumes.
                 # btrfs subvolume IDs are only unique for one same btrfs filesystem
                 # which is the case here because the btrfs_device_and_mountpoint is fixed herein
@@ -320,7 +327,7 @@ fi
                 # When there are no snapshot subvolumes $snapshot_subvolumes_pattern variable will be empty.
                 # This special case must be handled properly when setting up $subvolumes_exclude_pattern
                 # otherwise ReaR would not recreate the btrfs subvolumes during recovery
-                # because an empty pattern in the below egrep -v '|...' command would
+                # because an empty pattern in the below grep -Ev '|...' command would
                 # exclude all lines (see https://github.com/rear/rear/pull/1435):
                 if test -z "$snapshot_subvolumes_pattern" ; then
                     subvolumes_exclude_pattern=""
@@ -349,7 +356,7 @@ fi
                     # for all devices except '/dev/sda3' where btrfs_subvolumes_setup_SLES() is called to setup that btrfs filesystem
                     # cf. https://github.com/rear/rear/pull/2080#discussion_r265046317 and see the code in the
                     # usr/share/rear/layout/prepare/GNU/Linux/133_include_mount_filesystem_code.sh script:
-                    IsInArray "$btrfs_device" "${BTRFS_SUBVOLUME_SLES_SETUP[@]}" || btrfs_subvolume_sles_setup_devices="$btrfs_subvolume_sles_setup_devices $btrfs_device"
+                    IsInArray "$btrfs_device" "${BTRFS_SUBVOLUME_SLES_SETUP[@]}" || btrfs_subvolume_sles_setup_devices+=" $btrfs_device"
                     # SLES 12 SP1 (or later) normal subvolumes that belong to snapper are excluded from being recreated:
                     # Snapper's base subvolume '/@/.snapshots' is excluded because during "rear recover"
                     # that one will be created by "snapper/installation-helper --step 1" which fails if it already exists
@@ -366,7 +373,7 @@ fi
                     # $snapshot_subvolumes_pattern variable will be empty. This special case
                     # must be handled properly when setting up $subvolumes_exclude_pattern
                     # otherwise ReaR would not recreate the btrfs subvolumes during recovery
-                    # because an empty pattern in the below egrep -v '|...' command would
+                    # because an empty pattern in the below grep -Ev '|...' command would
                     # exclude all lines (see https://github.com/rear/rear/pull/1435):
                     if test -z "$snapshot_subvolumes_pattern" ; then
                         subvolumes_exclude_pattern="$snapper_base_subvolume"
@@ -391,19 +398,19 @@ fi
                         echo "# Because any '@/.snapshots' subvolume would let 'snapper/installation-helper --step 1' fail"
                         echo "# such subvolumes are deactivated here to not let 'rear recover' fail:"
                         if test -z "$snapshot_subvolumes_pattern" ; then
-                            # With an empty snapshot_subvolumes_pattern egrep -v '' would exclude all lines:
+                            # With an empty snapshot_subvolumes_pattern grep -Ev '' would exclude all lines:
                             echo "$subvolume_list" | grep "$snapper_base_subvolume" | sed -e "s/^/#$prefix /"
                         else
-                            echo "$subvolume_list" | egrep -v "$snapshot_subvolumes_pattern" | grep "$snapper_base_subvolume" | sed -e "s/^/#$prefix /"
+                            echo "$subvolume_list" | grep -Ev "$snapshot_subvolumes_pattern" | grep "$snapper_base_subvolume" | sed -e "s/^/#$prefix /"
                         fi
                     fi
                 fi
                 # Output btrfs normal subvolumes:
                 if test -z "$subvolumes_exclude_pattern" ; then
-                    # With an empty subvolumes_exclude_pattern egrep -v '' would exclude all lines:
+                    # With an empty subvolumes_exclude_pattern grep -Ev '' would exclude all lines:
                     echo "$subvolume_list" | sed -e "s/^/$prefix /"
                 else
-                    echo "$subvolume_list" | egrep -v "$subvolumes_exclude_pattern" | sed -e "s/^/$prefix /"
+                    echo "$subvolume_list" | grep -Ev "$subvolumes_exclude_pattern" | sed -e "s/^/$prefix /"
                 fi
             fi
         done
@@ -434,6 +441,7 @@ fi
                     # Output header only once:
                     btrfsmountedsubvol_entry_exists="yes"
                     echo "# All mounted btrfs subvolumes (including mounted btrfs default subvolumes and mounted btrfs snapshot subvolumes)."
+                    echo "# Mounted btrfs snapshot subvolumes are autoexcluded."
                     if test "$findmnt_FSROOT_works" ; then
                         echo "# Determined by the findmnt command that shows the mounted btrfs_subvolume_path."
                         echo "# Format: btrfsmountedsubvol <device> <subvolume_mountpoint> <mount_options> <btrfs_subvolume_path>"
@@ -453,10 +461,10 @@ fi
                     # (using subvolid=... can fail because the subvolume ID can be different during system recovery).
                     # Because both "mount ... -o subvol=/path/to/subvolume" and "mount ... -o subvol=path/to/subvolume" work
                     # the subvolume path can be specified with or without leading '/'.
-                    # Aviod SC1087 by using ${subvolume_mountpoint} with curly brackets because
+                    # Avoid SC1087 by using ${subvolume_mountpoint} with curly brackets because
                     # we need the subsequent square brackets literally (subvolume_mountpoint is a string, not an array):
-                    btrfs_subvolume_path=$( egrep "[[:space:]]${subvolume_mountpoint}[[:space:]]+btrfs[[:space:]]" /etc/fstab \
-                                            | egrep -v '^[[:space:]]*#' \
+                    btrfs_subvolume_path=$( grep -E "[[:space:]]${subvolume_mountpoint}[[:space:]]+btrfs[[:space:]]" /etc/fstab \
+                                            | grep -E -v '^[[:space:]]*#' \
                                             | grep -o 'subvol=[^ ]*' | cut -s -d '=' -f 2 )
                 fi
                 # Remove leading '/' from btrfs_subvolume_path (except it is only '/') to have same syntax for all entries and
@@ -469,7 +477,10 @@ fi
                 # Finally, test whether the btrfs subvolume listed as mounted actually exists. A running docker
                 # daemon apparently can convince the system to list a non-existing btrfs volume as mounted.
                 # See https://github.com/rear/rear/issues/1496
-                if btrfs_subvolume_exists "$subvolume_mountpoint" "$btrfs_subvolume_path"; then
+                if btrfs_snapshot_subvolume_exists "$subvolume_mountpoint" "$btrfs_subvolume_path"; then
+                    # Exclude mounted snapshot subvolumes
+                    echo "#btrfsmountedsubvol $device $subvolume_mountpoint $mount_options $btrfs_subvolume_path"
+                elif btrfs_subvolume_exists "$subvolume_mountpoint" "$btrfs_subvolume_path"; then
                     echo "btrfsmountedsubvol $device $subvolume_mountpoint $mount_options $btrfs_subvolume_path"
                 else
                     LogPrintError "Ignoring non-existing btrfs subvolume listed as mounted: $subvolume_mountpoint"
@@ -500,8 +511,10 @@ fi
                     # see https://btrfs.wiki.kernel.org/index.php/Mount_options
                     test "/" != "$btrfs_subvolume_path" && btrfs_subvolume_path=${btrfs_subvolume_path#/}
                     if test -n "$btrfs_subvolume_path" ; then
-                        # Add the following binaries to the rescue image in order to be able to change required attrs uppon recovery.
-                        PROGS+=( chattr lsattr )
+                        # Add the following binaries to the rescue image in order to be able to change required attrs upon recovery.
+                        # See conf/examples/SLE12-SP2-btrfs-example.conf and https://github.com/rear/rear/issues/2927
+                        REQUIRED_PROGS+=( chattr )
+                        PROGS+=( lsattr )
                         echo "btrfsnocopyonwrite $btrfs_subvolume_path"
                     else
                         echo "# $subvolume_mountpoint has the 'no copy on write' attribute set but $findmnt_command does not show its btrfs subvolume path"
@@ -512,8 +525,6 @@ fi
             echo "# Attributes cannot be determined because no executable 'lsattr' and/or 'findmnt' command(s) found that supports 'FSROOT'."
         fi
 
-        # This needs to be done inside the subshell (that appends its stdout to DISKLAYOUT_FILE)
-        # because outside the subshell the inside the subshell set variables would be lost:
         if test "$btrfs_subvolume_sles_setup_devices" ; then
             # Save the updated BTRFS_SUBVOLUME_SLES_SETUP array variable that is needed in recover mode into the rescue.conf file:
             cat - <<EOF >> "$ROOTFS_DIR/etc/rear/rescue.conf"
@@ -534,8 +545,8 @@ EOF
     # End btrfs subvolume layout if a btrfs filesystem exists:
     fi
 
-) >> $DISKLAYOUT_FILE
-# End of the subshell that appends its stdout to DISKLAYOUT_FILE.
+} 1>>$DISKLAYOUT_FILE
+# End of group command that appends its stdout to DISKLAYOUT_FILE
 
 # mkfs is required in the recovery system if disklayout.conf contains at least one 'fs' entry
 # see the create_fs function in layout/prepare/GNU/Linux/130_include_filesystem_code.sh
