@@ -10,7 +10,7 @@
 # This file is part of Relax-and-Recover, licensed under the GNU General
 # Public License. Refer to the included COPYING for full text of license.
 
-# The sequence $'...' is an special bash expansion with backslash-escaped characters
+# The sequence $'...' is a special bash expansion with backslash-escaped characters
 # see "Words of the form $'string' are treated specially" in "man bash"
 # that works at least down to bash 3.1 in SLES10:
 LF=$'\n'
@@ -158,7 +158,7 @@ function terminate_descendants_from_grandchildren_to_children () {
         if kill -0 $descendant_pid ; then
             # Keep the current ordering also in not_yet_terminated_pids
             # i.e. grandchildren before children:
-            not_yet_terminated_pids="$not_yet_terminated_pids $descendant_pid"
+            not_yet_terminated_pids+=" $descendant_pid"
             LogPrint "Descendant process $descendant_pid not yet terminated"
         fi
     done
@@ -251,7 +251,7 @@ function terminate_descendants_from_children_to_grandchildren () {
         if kill -0 $descendant_pid ; then
             # Keep the current ordering also in not_yet_terminated_pids
             # i.e. children before grandchildren:
-            not_yet_terminated_pids="$not_yet_terminated_pids $descendant_pid"
+            not_yet_terminated_pids+=" $descendant_pid"
             LogPrint "Child process $descendant_pid not yet terminated"
         fi
     done
@@ -303,8 +303,9 @@ function DoExitTasks () {
     # terminate_descendants_from_children_to_grandchildren that sleeps two times one second
     # so that we wait here three seconds to be on the safe side that a possibly running
     # terminate_descendants_from_children_to_grandchildren has done its job and finished
-    # to avoid that two functions run in parallel that terminate descendant processes:
-    sleep 3
+    # to avoid that two functions run in parallel that terminate descendant processes.
+    # Skip sleeping when all went well and DoExitTasks is called at normal exit:
+    (( EXIT_FAIL_MESSAGE )) && sleep 3
     # Show descendant processes PIDs with their commands in the log
     # so that the plain PIDs in the log get more comprehensible
     # when terminate_descendants_from_grandchildren_to_children is called afterwards:
@@ -406,11 +407,11 @@ function PrintError () {
 # For messages that should only appear in the log file output to the current STDERR
 # because (usually) the current STDERR is redirected to the log file:
 function Log () {
-    # RUNTIME_LOGFILE does not yet exists in case of early Error() in usr/sbin/rear
-    test -w "$RUNTIME_LOGFILE" || return 0
-    # Have a timestamp with nanoseconds precision in any case
-    # so that any subsequent Log() calls get logged with precise timestamps:
-    { local timestamp=$( date +"%Y-%m-%d %H:%M:%S.%N " )
+    { # RUNTIME_LOGFILE does not yet exists in case of early Error() in usr/sbin/rear
+      test -w "$RUNTIME_LOGFILE" || return 0
+      # Have a timestamp with nanoseconds precision in any case
+      # so that any subsequent Log() calls get logged with precise timestamps:
+      local timestamp=$( date +"%Y-%m-%d %H:%M:%S.%N " )
       local prefix="${MESSAGE_PREFIX}${timestamp}"
       # prefix_blanks has the printable characters in prefix replaced with blanks for indentation:
       local prefix_blanks="$( tr '[:print:]' ' ' <<<"$prefix" )"
@@ -437,51 +438,84 @@ function Log () {
       #   # prefix_blanks="$( tr '[:print:]' ' ' <<<"$prefix" )"
       #   # log_message="${MESSAGE_PREFIX}${timestamp}${message//$'\n'/$'\n'$prefix_blanks}"
       #   # echo "$log_message"
-      #   message prefix 2021-06-24 10:49:39.824719000 fist line'
+      #   message prefix 2021-06-24 10:49:39.824719000 first line'
       #   '                                             second line'
       #   '                                             third line
       # so we use the LF variable (cf. how LF is set above)
       #   # LF=$'\n'
       #   # log_message="${MESSAGE_PREFIX}${timestamp}${message//$LF/$LF$prefix_blanks}"
       #   # echo "$log_message"
-      #   message prefix 2021-06-24 10:49:39.824719000 fist line
+      #   message prefix 2021-06-24 10:49:39.824719000 first line
       #                                                second line
       #                                                third line
-      # to make that parameter expansion also works with bash version 3.1.17 in SLES10:
+      # to make that parameter expansion also work with bash version 3.1.17 in SLES10:
       log_message="${MESSAGE_PREFIX}${timestamp}${message//$LF/$LF$prefix_blanks}"
+      # Append the log message explicitly to the log file to ensure that intended log messages
+      # actually appear in the log file even inside { ... } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+      # e.g. as in { COMMAND || Log "COMMAND failed" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+      # cf. the 2>>/dev/$DISPENSABLE_OUTPUT_DEV usage in the RequiredSharedObjects function
+      # and in build/GNU/Linux/100_copy_as_is.sh and build/GNU/Linux/390_copy_binaries_libraries.sh
+      echo "$log_message" >>"$RUNTIME_LOGFILE" || true
     } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
-    # Append the log message explicitly to the log file to ensure that intended log messages
-    # actually appear in the log file even inside { ... } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
-    # e.g. as in { COMMAND || Log "COMMAND failed" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
-    # cf. the 2>>/dev/$DISPENSABLE_OUTPUT_DEV usage in the RequiredSharedObjects function
-    # and in build/GNU/Linux/100_copy_as_is.sh and build/GNU/Linux/390_copy_binaries_libraries.sh
-    echo "$log_message" >>"$RUNTIME_LOGFILE" || true
+}
+
+# For messages that should only appear in the log file when EXPOSE_SECRETS is set.
+# Usage example:
+#   if { COMMAND $SECRET_ARGUMENT ; } 2>>/dev/$SECRET_OUTPUT_DEV ; then
+#       { LogSecret "'COMMAND $SECRET_ARGUMENT' succeeded" || Log "COMMAND succeeded" ; } 2>>/dev/$SECRET_OUTPUT_DEV
+#   else
+#       { LogSecret "'COMMAND $SECRET_ARGUMENT' failed with exit code $?" ; } 2>>/dev/$SECRET_OUTPUT_DEV
+#       Error "COMMAND failed"
+#   fi
+# Every LogSecret function call must be within '{ ... ; } 2>>/dev/$SECRET_OUTPUT_DEV'
+# because otherwise $SECRET_ARGUMENT in the LogSecret function call
+# would leak into the log file in debuscript mode via 'set -x'
+# in particular also when there is no directly visible secret argument
+# but command substitution may result confidential information like
+#   { LogSecret "The value is: $( COMMAND )" ; } 2>>/dev/$SECRET_OUTPUT_DEV
+# because 'set -x' prints the result of COMMAND as part of the LogSecret argument.
+# The "COMMAND ... succeeded" log messages are needed
+# to have something in the log about COMMAND because the command call itself
+# gets not logged (also not in debugscript mode) unless EXPOSE_SECRETS is set,
+# cf. https://github.com/rear/rear/issues/2967
+# The command's failure exit code '$?' is only available when
+#   if COMMAND ; then ... ; else Log "COMMAND failed with exit code $?" ; fi
+# is used because when 'if ! COMMAND' would be used then '!' results $?=0
+# cf. https://github.com/rear/rear/pull/2985#issuecomment-1545455356
+function LogSecret () {
+    # The LogSecret function returns a non-zero exit code (the exit code of 'test "$EXPOSE_SECRETS"')
+    # when EXPOSE_SECRETS is not set which can be used to log a generic fallback message like:
+    #   { LogSecret "SECRET message" || Log "generic message" ; } 2>>/dev/$SECRET_OUTPUT_DEV
+    { test "$EXPOSE_SECRETS" && Log "$@" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For messages that should only appear in the log file when the user launched 'rear -d' in debug mode:
 function Debug () {
-    test "$DEBUG" && Log "$@" || true
+    { test "$DEBUG" && Log "$@" || true ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For messages that should appear in the log file when the user launched 'rear -d' in debug mode and
 # that also appear on the user's terminal (in debug mode the verbose mode is set automatically):
 function DebugPrint () {
-    Debug "$@"
-    test "$DEBUG" && Print "$@" || true
+    { Debug "$@"
+      test "$DEBUG" && Print "$@" || true
+    } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For messages that should appear in the log file and also
 # on the user's terminal when the user launched 'rear -v' in verbose mode:
 function LogPrint () {
-    Log "$@"
-    Print "$@"
+    { Log "$@"
+      Print "$@"
+    } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For output plus logging that is intended for user dialogs.
 # 'LogUserOutput' belongs to 'UserOutput' like 'LogPrint' belongs to 'Print':
 function LogUserOutput () {
-    Log "$@"
-    UserOutput "$@"
+    { Log "$@"
+      UserOutput "$@"
+    } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For important messages that should appear in the log file and also
@@ -501,14 +535,36 @@ function LogUserOutput () {
 # Messages that are no real error messages should not be prefixed with 'Warning: '
 # cf. https://blog.schlomo.schapiro.org/2015/04/warning-is-waste-of-my-time.html
 function LogPrintError () {
-    Log "$@"
-    PrintError "$@"
+    { Log "$@"
+      PrintError "$@"
+    } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # For messages that should only appear in the syslog:
 function LogToSyslog () {
     # Send a line to syslog or messages file with input string with the tag 'rear':
-    logger -t rear -i "${MESSAGE_PREFIX}$*"
+    { logger -t rear -i "${MESSAGE_PREFIX}$*" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+}
+
+# Remove leading space and tab characters from input lines
+# and prefix each line with the argument string if specified.
+# When no argument is specified each line is prefixed/indented with two spaces.
+# When an empty argument is specified only leading space and tab characters are removed.
+# The intent is to be able to properly indent multi-line message strings in the code and
+# output the message without the code indentation but prefixed as needed for example like
+#   message="first line
+#            second line
+#            last line"
+#   LogPrint "Message text:$LF$( TextPrefix ' | ' <<<"$message" )"
+# which results the following output
+# Message text:
+#  | first line
+#  | second line
+#  | last line
+function TextPrefix () {
+    { local prefix="${1-  }"
+      sed -e "s/^[ \t]*/$prefix/"
+    } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
 }
 
 # Check if any of the arguments is executable (logical OR condition).
@@ -636,7 +692,7 @@ function Error () {
     # Add two spaces indentation for better readability what those extracted log file lines are.
     # Some messages could be too long to be usefully shown on the user's terminal so that they are truncated after 200 bytes:
     if test -s "$RUNTIME_LOGFILE" ; then
-        { local last_sourced_script_log_messages="$( sed -n -e "/Including .*$last_sourced_script_filename/,/+ [Bug]*Error /p" $RUNTIME_LOGFILE | egrep -v "^\+|Including .*$last_sourced_script_filename" | tail -n 8 | sed -e 's/^/  /' | cut -b-200 )" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+        { local last_sourced_script_log_messages="$( sed -n -e "/Including .*$last_sourced_script_filename/,/+ [Bug]*Error /p" $RUNTIME_LOGFILE | grep -E -v "^\+|Including .*$last_sourced_script_filename" | tail -n 8 | sed -e 's/^/  /' | cut -b-200 )" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
         if test "$last_sourced_script_log_messages" ; then
             PrintError "Some latest log messages since the last called script $last_sourced_script_filename:"
             PrintError "$last_sourced_script_log_messages"
@@ -648,7 +704,7 @@ function Error () {
     if test -f "$STDOUT_STDERR_FILE" ; then
         # We use the same extraction pipe as above because STDOUT_STDERR_FILE may also contain 'set -x' and things like that
         # because scripts could use 'set -x' and things like that as needed (e.g. diskrestore.sh runs with 'set -x'):
-        { local last_sourced_script_stdout_stderr_messages="$( sed -n -e "/Including .*$last_sourced_script_filename/,/+ [Bug]*Error /p" $STDOUT_STDERR_FILE | egrep -v "^\+|Including .*$last_sourced_script_filename" | tail -n 8 | sed -e 's/^/  /' | cut -b-200 )" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+        { local last_sourced_script_stdout_stderr_messages="$( sed -n -e "/Including .*$last_sourced_script_filename/,/+ [Bug]*Error /p" $STDOUT_STDERR_FILE | grep -E -v "^\+|Including .*$last_sourced_script_filename" | tail -n 8 | sed -e 's/^/  /' | cut -b-200 )" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
         if test "$last_sourced_script_stdout_stderr_messages" ; then
             # When stdout and stderr are redirected to STDOUT_STDERR_FILE messages of the last called programs cannot be in the log
             # so we use LogPrintError and 'echo "string of messages" >>$RUNTIME_LOGFILE' (the latter avoids the timestamp prefix)
@@ -684,7 +740,7 @@ function Error () {
     # We must send USR1 to MASTER_PID before we terminate all still running descendant processes of MASTER_PID below
     # because when the Error function is called from a subshell we are one of those still running descendant processes:
     kill -USR1 $MASTER_PID
-    # That USR1 has a trap (see above) that does 'kill MASTER_PID' whicht triggers another trap on EXIT that calls DoExitTasks().
+    # That USR1 has a trap (see above) that does 'kill MASTER_PID' which triggers another trap on EXIT that calls DoExitTasks().
     # When the Error function is called from within a subshell (cf. layout/save/GNU/Linux/230_filesystem_layout.sh) like 
     #   ( echo "additional content for file" || Error "failed to append content to file" ) >> file
     # the Error function does not let MASTER_PID exit because the parent shell waits until its subshell has finished
@@ -765,7 +821,7 @@ function Error () {
     terminate_descendants_from_children_to_grandchildren
     # Now only the process that runs this code here is left.
     # If that process is MASTER_PID all is o.k. but if that process is run within a subshell
-    # we must not return here from the Error funtion to its caller because that would let
+    # we must not return here from the Error function to its caller because that would let
     # the subshell continue with all its code after the Error function until the subshell finishes
     # so that if we are in a subshell here we exit from that subshell here:
     if test $BASH_SUBSHELL -gt 0 ; then
@@ -783,7 +839,7 @@ function BugError () {
     Error "
 ====================
 BUG in $caller_source:
-'$*'
+$*
 --------------------
 Please report it at $BUG_REPORT_SITE
 and include all related parts from $RUNTIME_LOGFILE
@@ -791,8 +847,44 @@ preferably the whole debug information via 'rear -D $WORKFLOW'
 ===================="
 }
 
+# Error out with a deprecation info
+# first arg is feature keyword
+# everything else is a reason for the deprecation
+function ErrorIfDeprecated () {
+    (( $# >= 2 )) || BugError "Must call ErrorIfDeprecated with at least 2 arguments - feature and reason"
+    local feature="$1" ; shift
+
+    if IsInArray "$feature" "${DISABLE_DEPRECATION_ERRORS[@]}" ; then
+        LogPrint "Disabled deprecation error for '$feature'"
+        return 0
+    fi
+
+    local reason="$*"
+
+    local error_text="Deprecation of '$feature'
+        Reason:
+        $reason
+
+        This feature is phased out in ReaR and will be eventually removed.
+        If it is indispensable, go to https://github.com/rear/rear/issues
+        and create an issue that explains why there is no alternative to it.
+
+        To disable this error and continue using this feature for now, set
+        DISABLE_DEPRECATION_ERRORS+=( $feature )
+        "
+    # Remove leading space and tab characters (fail-safe if $reason lines are indented with tabs):
+    Error "$( sed -e 's/^[ \t]*//' <<<"$error_text" )"
+}
+
+# The ...IfError functions should no longer be used in new code and
+# when existing code is modified the existing ...IfError functions
+# should be replaced by using bash directly (see the examples below).
+#
+# Reason:
 # Using the ...IfError functions can result unexpected behaviour in certain cases.
 #
+# Examples:
+#
 # Using $? in an ...IfError function message like
 #   COMMAND
 #   StopIfError "COMMAND failed with error code $?"
@@ -805,6 +897,20 @@ preferably the whole debug information via 'rear -D $WORKFLOW'
 #   cat: QQQ: No such file or directory
 #   ERROR 1
 # works as expected.
+# By the way:
+# Using $? with 'if ! ...' like
+#   if ! COMMAND ; then echo "COMMAND failed with $?" ; fi
+# does not work because '!' changes/inverts '$?' for example as in
+#   # if ! cat QQQ ; then echo "cat QQQ failed with $?" ; fi
+#   cat: QQQ: No such file or directory
+#   cat QQQ failed with 0
+# cf. https://github.com/rear/rear/pull/2985#issuecomment-1545455356
+# so one should avoid 'if ! ...' like
+#   if COMMAND ; then ... ; else echo "COMMAND failed with $?" ; fi
+# for example as in
+#   # if cat QQQ ; then : ; else echo "cat QQQ failed with $?" ; fi
+#   cat: QQQ: No such file or directory
+#   cat QQQ failed with 1
 #
 # The ...IfError functions fail when 'set -e' is set
 # cf. https://github.com/rear/rear/issues/534
@@ -918,7 +1024,7 @@ function cleanup_build_area_and_end_program () {
             sleep 2
             # umount_mountpoint_lazy is in lib/global-functions.sh
             # which is not yet sourced in case of early Error() in usr/sbin/rear
-            has_binary umount_mountpoint_lazy && umount_mountpoint_lazy $BUILD_DIR/outputfs
+            has_binary umount_mountpoint_lazy && umount_mountpoint_lazy "$BUILD_DIR/outputfs"
         fi
         # remove_temporary_mountpoint is in lib/global-functions.sh
         # which is not yet sourced in case of early Error() in usr/sbin/rear
@@ -953,7 +1059,7 @@ function cleanup_build_area_and_end_program () {
 #       Usually this is one of the choice values or one of the a choice numbers '1' '2' '3' ...
 #       that are shown to the user (the choice numbers are shown as in 'select' (i.e. starting at 1)
 #       but the default input can be anything else (in particular for free input without predefined choices)
-#       so that e.g. '-D 0' is not the first choice but lets the default input be '0' (regardles of choices).
+#       so that e.g. '-D 0' is not the first choice but lets the default input be '0' (regardless of choices).
 #   The option '-I user_input_ID' is required so that UserInput can work full automated (e.g. when ReaR runs unattended)
 #       via user-specified variables that get named USER_INPUT_user_input_ID (i.e. prefixed with 'USER_INPUT_')
 #       so that the user can (as he needs it) predefine user input values like
@@ -979,12 +1085,18 @@ function cleanup_build_area_and_end_program () {
 #       appear in the log file so that the confidential user input mode does not help in debugscript mode.
 #       If confidential user input is needed also in debugscript mode the caller of the UserInput function
 #       must call it in an appropriate (temporary) environment e.g. with STDERR redirected to /dev/null like
-#           { password="$( UserInput -I PASSWORD -C -r -s -p 'Enter the pasword' )" ; } 2>/dev/null
-#       The redirection must be done via a compound group command { confidential_command ; } 2>/dev/null
+#           { password="$( UserInput -I PASSWORD -C -r -s -p 'Enter the password' )" ; } 2>/dev/null
+#       or since https://github.com/rear/rear/pull/3006 probably better as
+#           { password="$( UserInput -I PASSWORD -C -r -s -p 'Enter the password' )" ; } 2>>/dev/$SECRET_OUTPUT_DEV
+#       to still make debugging possible for the user by calling rear with the --expose-secrets option.
+#       The redirection must be done via a compound group command like
+#           { confidential_command ; } 2>/dev/null
 #       even for a single confidential command to ensure STDERR is redirected to /dev/null also for 'set -x'
 #       otherwise the confidential command and its arguments would be shown in the log file, for example
 #           { openssl des3 -salt -k secret_passphrase ; } 2>/dev/null
-#       where the secret passphrase must not appear in the log, cf. https://github.com/rear/rear/issues/2155
+#       where the secret passphrase must not appear in the log,
+#       cf. https://github.com/rear/rear/issues/2155
+#       and https://github.com/rear/rear/issues/2967
 # Result:
 #   Any actual user input or an automated user input or the default response is output via STDOUT.
 # Return code:
@@ -1038,7 +1150,14 @@ function cleanup_build_area_and_end_program () {
 #       USER_INPUT_BAR_CHOICE='third choice'
 #   which lets a 'UserInput -I BAR_CHOICE' call autorespond with 'third choice'.
 #   No USER_INPUT_BAR_CHOICE variable should exist to get real user input for a 'UserInput -I BAR_CHOICE' call
-#   or the user can interupt any automated response within a relatively short time (minimum is only 1 second).
+#   or the user can interrupt any automated response within a relatively short time (minimum is only 1 second).
+# * The non-interactive feature works by erroring out in UserInput if the same user input ID is used more than once and
+#   if the first call to UserInput was not met by a human response. The idea is that if the first call ran into the
+#   timeout then the second call will not have a better chance of success and should be treated as an error.
+#   That way, ReaR will quickly abort in situations where human intervention is required but not provided.
+#   This is implemented via the Bash array USER_INPUT_SEEN_WITH_TIMEOUT which tracks which user input IDs
+#   were already used and ran into the timeout.
+declare -a USER_INPUT_SEEN_WITH_TIMEOUT
 function UserInput () {
     # First and foremost log that UserInput was called (but be confidential here):
     local caller_source="$( CallerSource )"
@@ -1053,11 +1172,15 @@ function UserInput () {
     # that would (without the delay) run in a tight loop that wastes resources (CPU, diskspace, and memory)
     # and fills up the ReaR log file (and the disk - which is a ramdisk for 'rear recover')
     # with some KiB data each second that may let 'rear recover' fail with 'out of diskspace/memory'.
-    # The default automated input interrupt timeout is 5 seconds to give the user a reasonable chance
+    # The default automated input interrupt timeout is 30 seconds to give the user a reasonable chance
     # to recognize the right automated input on his screen and interrupt it when needed:
-    local automated_input_interrupt_timeout=5
+    local automated_input_interrupt_timeout=30
     # Avoid stderr if USER_INPUT_INTERRUPT_TIMEOUT is not set or empty and ignore wrong USER_INPUT_INTERRUPT_TIMEOUT:
     test "$USER_INPUT_INTERRUPT_TIMEOUT" -ge 1 2>/dev/null && automated_input_interrupt_timeout=$USER_INPUT_INTERRUPT_TIMEOUT
+    # Have at least one second timeout when ReaR runs unattended (in particular in non-interactive mode)
+    # because 'read -t 0' would return immediately without trying to read any data:
+    local unattended_timeout=3
+    test "$USER_INPUT_UNATTENDED_TIMEOUT" -ge 1 2>/dev/null && unattended_timeout=$USER_INPUT_UNATTENDED_TIMEOUT
     local default_prompt="enter your input"
     local prompt="$default_prompt"
     # Avoid stderr if USER_INPUT_PROMPT is not set or empty:
@@ -1081,7 +1204,11 @@ function UserInput () {
         case $option in
             (t)
                 # Avoid stderr if OPTARG is not set or empty or not an integer value:
-                test "$OPTARG" -ge 0 2>/dev/null && timeout=$OPTARG || Log "UserInput: Invalid -$option argument '$OPTARG' using fallback '$timeout'"
+                if test "$OPTARG" -ge 0 2>/dev/null ; then
+                    timeout=$OPTARG
+                else
+                    Log "UserInput: Invalid -$option argument '$OPTARG' using fallback '$timeout'"
+                fi
                 ;;
             (p)
                 prompt="$OPTARG"
@@ -1091,7 +1218,11 @@ function UserInput () {
                 ;;
             (n)
                 # Avoid stderr if OPTARG is not set or empty or not an integer value:
-                test "$OPTARG" -ge 0 2>/dev/null && input_max_chars=$OPTARG || Log "UserInput: Invalid -$option argument '$OPTARG' using fallback '$input_max_chars'"
+                if test "$OPTARG" -ge 0 2>/dev/null ; then
+                    input_max_chars=$OPTARG
+                else
+                    Log "UserInput: Invalid -$option argument '$OPTARG' using fallback '$input_max_chars'"
+                fi
                 ;;
             (d)
                 input_delimiter="$OPTARG"
@@ -1121,7 +1252,12 @@ function UserInput () {
     done
     test $user_input_ID || BugError "UserInput: Option '-I user_input_ID' required"
     test "$( echo $user_input_ID | tr -c -d '[:lower:]' )" && BugError "UserInput: Option '-I' argument '$user_input_ID' must not contain lower case letters"
-    declare $user_input_ID="dummy" || BugError "UserInput: Option '-I' argument '$user_input_ID' not a valid variable name"
+    declare $user_input_ID="dummy" 2>/dev/null || BugError "UserInput: Option '-I' argument '$user_input_ID' not a valid variable name"
+    # In non-interactive mode use a short timeout (by default 3 seconds):
+    if is_true "$NON_INTERACTIVE" ; then
+        timeout=$unattended_timeout
+        automated_input_interrupt_timeout=$unattended_timeout
+    fi
     # Shift away the options and arguments:
     shift "$(( OPTIND - 1 ))"
     # Everything that is now left in "$@" is neither an option nor an option argument
@@ -1167,7 +1303,7 @@ function UserInput () {
         # Avoid stderr if timeout is not set or empty or not an integer value:
         if test "$timeout" -ge 1 2>/dev/null ; then
             if test "$default_and_timeout" ; then
-                default_and_timeout="$default_and_timeout timeout $timeout seconds"
+                default_and_timeout+=" timeout $timeout seconds"
             else
                 default_and_timeout="timeout $timeout seconds"
             fi
@@ -1177,6 +1313,33 @@ function UserInput () {
     # In debug mode show the user the script that called UserInput and what user_input_ID was specified
     # so that the user can prepare an automated response for that UserInput call (without digging in the code):
     DebugPrint "UserInput -I $user_input_ID needed in $caller_source"
+    # Drain stdin if stdin is a terminal i.e. when 'rear' is run in interactive mode
+    # where stdin normally is what the user types on his keyboard.
+    # In this case discard possibly already existing characters (in particular ENTER keystrokes) from stdin
+    # to avoid that when the user had accidentally hit ENTER more than once in a previous (UserInput) dialog
+    # then those additional ENTER characters would be already in stdin and let this current UserInput dialog
+    # proceed unintendedly automatically without an explicit ENTER from the user for this current dialog,
+    # see https://github.com/rear/rear/issues/2866
+    # and https://github.com/rear/rear/pull/2868#issuecomment-1257988466
+    # There is no generic and fail safe working way to clear stdin
+    # cf. https://superuser.com/questions/276531/clear-stdin-before-reading
+    # so we 'read' and discard what is already there up to 1000 characters
+    # which leaves characters in stdin if there are more than 1000 characters in stdin.
+    # It does not get unfinished lines in the terminal buffer which are not yet in stdin.
+    # Draining also the terminal buffer would require special things with 'stty' like
+    #   old_tty_settings=$( stty -g )
+    #   stty -icanon min 0 time 0
+    #   ... [read what is there]
+    #   stty $old_tty_settings
+    # but we do not like to mess around with the user's terminal settings in ReaR.
+    # That the 'read' timeout can be a fractional number requires bash 4.x
+    # see https://github.com/rear/rear/issues/2866#issuecomment-1254908270
+    # but in general ReaR should still work with bash 3.x so we use '-t 1'
+    # which would cause a one second delay when there is nothing in stdin
+    # until 'read' timed out which we avoid with 'read -t 0' before
+    # and we keep the '-t 1' in the subsequent 'read' to be fail safe
+    # see https://github.com/rear/rear/pull/2868#issuecomment-1259087491
+    test -t 0 && read -t 0 && read -s -t 1 -n 1000 -d ''
     # First of all show the prompt unless an empty prompt was specified (via -p '')
     # so that the prompt can be used as some kind of header line that introduces the user input
     # and separates the following user input from arbitrary other output lines before:
@@ -1196,20 +1359,26 @@ function UserInput () {
     if test "$default_and_timeout" ; then
         is_true "$confidential_mode" && UserOutput "($default_and_timeout)" || LogUserOutput "($default_and_timeout)"
     fi
-    # Prepare the 'read' call:
+    # In non-interactive mode error out if things do not proceed with default or automated input or without input and timeout:
+    if is_true "$NON_INTERACTIVE" ; then
+        if IsInArray "$user_input_ID" "${USER_INPUT_SEEN_WITH_TIMEOUT[@]}" 2>/dev/null ; then
+            Error "UserInput: non-interactive mode and repeat input request for '$user_input_ID' (previous attempt got default or automated input or timed out)"
+        fi
+    fi
+    # Prepare the 'read $read_options_and_arguments ...' call:
     local read_options_and_arguments=""
-    is_true "$raw_input" && read_options_and_arguments="$read_options_and_arguments -r"
-    is_true "$silent_input" && read_options_and_arguments="$read_options_and_arguments -s"
+    is_true "$raw_input" && read_options_and_arguments+=" -r"
+    is_true "$silent_input" && read_options_and_arguments+=" -s"
     # When a zero timeout was specified (via -t 0) do not use it.
     # Avoid stderr if timeout is not set or empty or not an integer value:
-    test "$timeout" -ge 1 2>/dev/null && read_options_and_arguments="$read_options_and_arguments -t $timeout"
+    test "$timeout" -ge 1 2>/dev/null && read_options_and_arguments+=" -t $timeout"
     # When no input_words_array_name was specified (via -a myarr) do not use it:
-    test "$input_words_array_name" && read_options_and_arguments="$read_options_and_arguments -a $input_words_array_name"
+    test "$input_words_array_name" && read_options_and_arguments+=" -a $input_words_array_name"
     # When zero input_max_chars was specified (via -n 0) do not use it.
     # Avoid stderr if input_max_chars is not set or empty or not an integer value:
-    test "$input_max_chars" -ge 1 2>/dev/null && read_options_and_arguments="$read_options_and_arguments -n $input_max_chars"
+    test "$input_max_chars" -ge 1 2>/dev/null && read_options_and_arguments+=" -n $input_max_chars"
     # When no input_delimiter was specified (via -d x) do not use it:
-    test "$input_delimiter" && read_options_and_arguments="$read_options_and_arguments -d $input_delimiter"
+    test "$input_delimiter" && read_options_and_arguments+=" -d $input_delimiter"
     # Get the actual user input value:
     local input_string=""
     # When a predefined user input value exists use that as automated user input:
@@ -1237,6 +1406,8 @@ function UserInput () {
             fi
         else
             input_string="${!predefined_input_variable_name}"
+            # non-interactive - remember that UserInput didn't get interactive user input
+            is_true "$NON_INTERACTIVE" && USER_INPUT_SEEN_WITH_TIMEOUT+=( "$user_input_ID" )
             # When a (non empty) input_words_array_name was specified it must contain all user input words:
             test "$input_words_array_name" && read -a "$input_words_array_name" <<<"$input_string"
         fi
@@ -1251,6 +1422,8 @@ function UserInput () {
             is_true "$confidential_mode" && Log "UserInput: 'read' got user input" || Log "UserInput: 'read' got as user input '$input_string'"
         else
             return_code=1
+            # non-interactive - remember that UserInput didn't get interactive user input
+            is_true "$NON_INTERACTIVE" && USER_INPUT_SEEN_WITH_TIMEOUT+=( "$user_input_ID" )
             # Continue in any case because in case of errors the default input is used.
             # Avoid stderr if timeout is not set or empty or not an integer value:
             if test "$timeout" -ge 1 2>/dev/null ; then
