@@ -60,7 +60,8 @@ function find_syslinux_modules_dir {
             # cf. https://github.com/rear/rear/issues/2792
             # tell the user in debug mode what is going on
             DebugPrint "Searching whole /usr for SYSLINUX modules directory (you may specify SYSLINUX_MODULES_DIR)"
-            file=$( find /usr -name "$1" 2>/dev/null | tail -1 )
+	    # issue #3350 - adding -xdev to find to avoid hanging NFS
+            file=$( find /usr -xdev -name "$1" 2>/dev/null | tail -1 )
             syslinux_modules_dir=$( dirname "$file" )        # /usr/lib/syslinux/modules/efi32
             syslinux_modules_dir=${syslinux_modules_dir%/*}  # /usr/lib/syslinux/modules
             if is_true $USING_UEFI_BOOTLOADER ; then
@@ -180,7 +181,7 @@ function set_syslinux_features {
 
 # Create a suitable syslinux configuration based on capabilities
 # the mandatory first argument is the full path to an existing directory where required binaries will be copied to
-# the optional second argment is the target flavour and defaults to isolinux
+# the optional second argument is the target flavour and defaults to isolinux
 function make_syslinux_config {
     test -d "$1" || BugError "make_syslinux_config: required first argument for BOOT_DIR missing"
     test -d "$SYSLINUX_DIR" || BugError "make_syslinux_config: required environment SYSLINUX_DIR '$SYSLINUX_DIR' not set or not a directory"
@@ -283,7 +284,7 @@ function make_syslinux_config {
         syslinux_menu "TABMSG Press [Tab] to edit options and [F1] for version info"
     fi
 
-    echo "timeout 300"
+    echo "timeout ${ISO_SYSLINUX_TIMEOUT:-$(( $USER_INPUT_TIMEOUT * 10 ))}"
     echo "#noescape 1"
     syslinux_menu title $PRODUCT v$VERSION
 
@@ -529,6 +530,53 @@ function get_root_disk_UUID {
     ( set -o pipefail ; mount | grep ' on / ' | awk '{print $1}' | xargs blkid -s UUID -o value || Error "Failed to get root disk UUID" )
 }
 
+# Detect whether actually GRUB 2 is installed and that test is to
+# check if grub-probe or grub2-probe is installed because
+# grub-probe or grub2-probe is only installed in case of GRUB 2.
+# Needed because one can't tell the GRUB version by looking at the MBR
+# (both GRUB 2 and GRUB Legacy have the string "GRUB" in their MBR).
+function is_grub2_installed () {
+    if type -p grub-probe >&2 || type -p grub2-probe >&2 ; then
+        Log "GRUB 2 is installed (grub-probe or grub2-probe exist)."
+        return 0
+    else
+        return 1
+    fi
+}
+
+# Determine whether a disk is worth detecting or installing GRUB on
+function is_disk_grub_candidate () {
+    local disk="$1"
+    local disk_partitions part
+    local label flags
+
+    # ToDo : validate $disk (does it even exist? Isn't it write-protected?)
+
+    # Installing grub on an LVM PV will wipe the metadata so we skip those
+    is_disk_a_pv "$disk" && return 1
+
+    label="$( get_disklabel_type "$disk" )" || return 1
+    # We don't care about the SUSE-specific 'gpt_sync_mbr' partition scheme
+    # anymore: https://github.com/rear/rear/pull/3145#discussion_r1481388431
+    if [ "$label" == gpt ] ; then
+        # GPT needs a special BIOS boot partition to store GRUB (BIOS version).
+        # Let's try to find it. It can be recognized as having the bios_grub flag.
+        disk_partitions=( $( get_child_components "$disk" "part" ) )
+        for part in "${disk_partitions[@]}" ; do
+            flags=( $( get_partition_flags "$part" ) )
+            IsInArray bios_grub "${flags[@]}" && return 0 # found!
+        done
+        # If a given GPT-partitioned disk does not contain a BIOS boot partition,
+        # GRUB for BIOS booting can not be installed into its MBR (grub-install errors out).
+        return 1
+    else
+        # Other disklabel types don't need anything special to install GRUB.
+        # The test for the PReP boot partition (finalize/Linux-ppc64le/660_install_grub2.sh)
+        # is a bit similar, but operates on the partition itself, not on the underlying disk.
+        return 0
+    fi
+}
+
 # Output GRUB2 configuration on stdout:
 # $1 is the kernel file with appropriate path for GRUB2 to load the kernel from within GRUB2's root filesystem
 # $2 is the initrd file with appropriate path for GRUB2 to load the initrd from within GRUB2's root filesystem
@@ -536,25 +584,25 @@ function get_root_disk_UUID {
 # so that kernel and initrd are /boot_mountpoint/path/to/kernel and /boot_mountpoint/path/to/initrd
 # and that boot partition gets set as root device name for GRUB2's
 # then $1 would have to be /path/to/kernel and $2 would have to be /path/to/initrd
-# $3 is an appropriate GRUB2 command to set its root device (usually via GRUB2's 'root' environment variable)
-# e.g. when the filesystem that contains kernel and initrd has the filesystem label REARBOOT
-# then $3 could be something like 'search --no-floppy --set root --label REARBOOT'
 function create_grub2_cfg {
     local grub2_kernel="$1"
     test "$grub2_kernel" || BugError "create_grub2_cfg function called without grub2_kernel argument"
-    DebugPrint "Configuring GRUB2 kernel $grub2_kernel"
+    DebugPrint "Let GRUB2 load kernel $grub2_kernel"
     local grub2_initrd="$2"
     test "$grub2_initrd" || BugError "create_grub2_cfg function called without grub2_initrd argument"
-    DebugPrint "Configuring GRUB2 initrd $grub2_initrd"
-    local grub2_search_root_command="$3"
-    if ! test "$grub2_search_root_command" ; then
-        test "$grub2_set_root" && grub2_search_root_command="set root=$grub2_set_root"
+    DebugPrint "Let GRUB2 load initrd $grub2_initrd"
+
+    # Before https://github.com/rear/rear/pull/3025 it was possible to call create_grub2_cfg()
+    # with a third argument that is a "search GRUB2 'root' device command" string:
+    test "$3" && BugError "create_grub2_cfg function must not be called with a third argument"
+    # Since https://github.com/rear/rear/pull/3025 GRUB2_SET_ROOT_COMMAND and/or GRUB2_SEARCH_ROOT_COMMAND must be specified:
+    if contains_visible_char "$GRUB2_SEARCH_ROOT_COMMAND" ; then
+        contains_visible_char "$GRUB2_SET_ROOT_COMMAND" && DebugPrint "Set GRUB2 default root device via '$GRUB2_SET_ROOT_COMMAND'"
+        DebugPrint "Let GRUB2 search root device via '$GRUB2_SEARCH_ROOT_COMMAND'"
+    else
+        contains_visible_char "$GRUB2_SET_ROOT_COMMAND" || BugError "create_grub2_cfg function called but neither GRUB2_SET_ROOT_COMMAND nor GRUB2_SEARCH_ROOT_COMMAND is specified"
+        DebugPrint "Set GRUB2 root device via '$GRUB2_SET_ROOT_COMMAND'"
     fi
-    if ! test "$grub2_search_root_command" ; then
-        test "$GRUB2_SEARCH_ROOT_COMMAND" && grub2_search_root_command="$GRUB2_SEARCH_ROOT_COMMAND"
-    fi
-    test "$grub2_search_root_command" || grub2_search_root_command="search --no-floppy --set=root --file /boot/efiboot.img"
-    DebugPrint "Configuring GRUB2 root device as '$grub2_search_root_command'"
 
     local grub2_default_menu_entry="$GRUB2_DEFAULT_BOOT"
     test "$grub2_default_menu_entry" || grub2_default_menu_entry="chainloader"
@@ -613,6 +661,9 @@ function create_grub2_cfg {
                 echo "terminal_input serial"
                 echo "terminal_output serial"
             fi
+        else
+            DebugPrint "No serial console in GRUB2 (USE_SERIAL_CONSOLE is not true)"
+            echo "echo 'No serial console (USE_SERIAL_CONSOLE was not true)'"
         fi
     }
 
@@ -632,7 +683,6 @@ menuentry "Relax-and-Recover (BIOS or UEFI without Secure Boot)" --id=rear {
     echo 'Loading initial ramdisk $grub2_initrd ...'
     initrd $grub2_initrd
 }
-
 menuentry "Relax-and-Recover (UEFI and Secure Boot)" --id=rear_secure_boot {
     insmod gzio
     insmod xzio
@@ -714,10 +764,14 @@ EOF
 
     # The actual work starts here.
     # Create and output GRUB2 configuration.
-    # Sleep 3 seconds before the GRUB2 menu replaces what there is on the screen
-    # so that the user has a chance to see possible (error) messages on the screen.
+    # Sleep (interruptible) USER_INPUT_INTERRUPT_TIMEOUT seconds (by default 30 seconds)
+    # before the GRUB2 menu replaces what there is on the screen
+    # so that the user can read and understand possible (error) messages on the screen.
     cat << EOF
-$grub2_search_root_command
+$GRUB2_SET_ROOT_COMMAND
+$GRUB2_SEARCH_ROOT_COMMAND
+echo "Using root device (\$root) - available devices are:"
+ls
 insmod all_video
 set gfxpayload=keep
 insmod part_gpt
@@ -727,8 +781,8 @@ $( create_grub2_serial_entry )
 set timeout="$grub2_timeout"
 set default="$grub2_default_menu_entry"
 set fallback="chainloader"
-echo 'Switching to GRUB2 boot menu...'
-sleep --verbose --interruptible 3
+echo 'Switching to GRUB boot menu...'
+sleep --verbose --interruptible $USER_INPUT_INTERRUPT_TIMEOUT
 $( create_grub2_rear_boot_entry )
 $( create_grub2_boot_next_entry )
 $( create_grub2_reboot_entry )
@@ -790,7 +844,7 @@ function make_pxelinux_config {
     echo "say ----------------------------------------------------------"
 
     # start with optional rear http entry if specified
-    if [[ ! -z $PXE_HTTP_URL ]] ; then    
+    if [[ "$PXE_HTTP_DOWNLOAD_URL" ]] ; then    
         case "$PXE_RECOVER_MODE" in
         "automatic")
             echo "say rear-automatic-http - Recover $HOSTNAME (HTTP) with auto-recover kernel option"
@@ -812,8 +866,8 @@ function make_pxelinux_config {
         echo "Rescue image kernel $KERNEL_VERSION ${IPADDR:+on $IPADDR} $(date -R)"
         echo "${BACKUP:+BACKUP=$BACKUP} ${OUTPUT:+OUTPUT=$OUTPUT} ${BACKUP_URL:+BACKUP_URL=$BACKUP_URL}"
         echo "ENDTEXT"
-        echo "    kernel $PXE_HTTP_URL/$PXE_KERNEL"
-        echo "    append initrd=$PXE_HTTP_URL/$PXE_INITRD root=/dev/ram0 vga=normal rw $KERNEL_CMDLINE $PXE_RECOVER_MODE"
+        echo "    kernel $PXE_HTTP_DOWNLOAD_URL/$PXE_KERNEL"
+        echo "    append initrd=$PXE_HTTP_DOWNLOAD_URL/$PXE_INITRD root=/dev/ram0 vga=normal rw $KERNEL_CMDLINE $PXE_RECOVER_MODE"
         echo "say ----------------------------------------------------------"
     fi
 
@@ -889,15 +943,15 @@ function make_pxelinux_config {
 function make_pxelinux_config_grub {
     net_default_server_opt=""
 
-    # Be sure that TFTP Server IP is set with TFTP_SERVER_IP Variable.
-    # else set it based on PXE_TFTP_UR variable.
+    # Be sure that TFTP Server IP is set with PXE_TFTP_IP Variable.
+    # else set it based on PXE_TFTP_UPLOAD_URL variable.
     if [[ -z $PXE_TFTP_IP ]] ; then
-        if [[ -z $PXE_TFTP_URL ]] ; then
-            LogPrintError "Can't find TFTP IP information. Variable TFTP_SERVER_IP or PXE_TFTP_URL with clear IP address must be set."
+        if [[ -z "$PXE_TFTP_UPLOAD_URL" ]] ; then
+            LogPrintError "Can't find TFTP IP information. Variable PXE_TFTP_IP or PXE_TFTP_UPLOAD_URL with clear IP address must be set."
             return
         else
-            # Get IP address from PXE_TFTP_URL (ex:http://xx.yy.zz.aa:port/foo/bar)
-            PXE_TFTP_IP=$(echo "$PXE_TFTP_URL" | awk -F'[/:]' '{ print $4 }')
+            # Get IP address from PXE_TFTP_UPLOAD_URL (ex:http://xx.yy.zz.aa:port/foo/bar)
+            PXE_TFTP_IP=$(echo "$PXE_TFTP_UPLOAD_URL" | awk -F'[/:]' '{ print $4 }')
 
             # If PXE_TFTP_IP is not an IP, it could be a FQDM that must be resolved to IP.
             # is_ip() function is defined in network-function.sh
