@@ -7,7 +7,8 @@ WORKFLOW_shell () {
         LogPrint "${BASH_SOURCE[0]} starts a bash within rear"
         return 0
     fi
-    export REAR_EVAL="$(declare -p | sed -e 's/^declare .. //' -e '/MASKS=/d' )"
+    # mask variables that cause errors in the ReaR Shell and use full declare syntax to support also associative Bash arrays
+    export REAR_EVAL="$(declare -p | grep -Ev 'declare .. (VERBOSE|MASTER_PID|WORKING_DIR|MASKS)=.*')"
     # Use the original STDIN STDOUT and STDERR when 'rear' was launched by the user:
-    bash --rcfile $SHARE_DIR/lib/bashrc.rear -i 0<&6 1>&7 2>&8
+    bash --rcfile $SHARE_DIR/lib/rear-shell.bashrc -i 0<&6 1>&7 2>&8
 }
