@@ -6,10 +6,10 @@ if is_false $TSM_RESULT_SAVE; then
     return
 fi
 
-# When PXE_TFTP_URL is defined, result files are directly copied on the remote
+# When PXE_TFTP_UPLOAD_URL is defined, result files are directly copied on the remote
 # PXE/TFTP server, and the local files are deleted (800_copy_to_tftp.sh).
-# So, no need to backup RESULT_FILES when PXE_TFTP_URL is defined.
-[[ ! -z "$PXE_TFTP_URL" ]] && return
+# So, no need to backup RESULT_FILES when PXE_TFTP_UPLOAD_URL is defined.
+[[ "$PXE_TFTP_UPLOAD_URL" ]] && return
 
 [ ${#RESULT_FILES[@]} -gt 0 ]
 StopIfError "No files to copy (RESULT_FILES is empty)"
