@@ -5,5 +5,6 @@
 Log "Running: /usr/openv/netbackup/bin/bplist command"
 LANG=C /usr/openv/netbackup/bin/bplist -l -s `date -d "-5 days" \
 	"+%m/%d/%Y"` / >/dev/null
-[ $? -gt 0 ] && LogPrint "WARNING: Netbackup bplist check failed with error code $?.
+rc=$?
+[ $rc -gt 0 ] && LogPrint "WARNING: Netbackup bplist check failed with error code ${rc}.
 See $RUNTIME_LOGFILE for more details."
