@@ -36,10 +36,20 @@ if (( ${#OPAL_PBA_PROGS[@]} == 0 && ${#OPAL_PBA_COPY_AS_IS[@]} == 0)) && has_bin
     LogPrintError "     interface for the PBA by setting OPAL_PBA_{PROGS,COPY_AS_IS,LIBS} to include Plymouth components."
 fi
 PROGS+=( "${OPAL_PBA_PROGS[@]}" clear )
-[[ -n "$OPAL_PBA_DEBUG_PASSWORD" ]] && REQUIRED_PROGS+=( openssl )
+{ test "$OPAL_PBA_DEBUG_PASSWORD" ; } 2>>/dev/$SECRET_OUTPUT_DEV && REQUIRED_PROGS+=( openssl )
 COPY_AS_IS+=( "${OPAL_PBA_COPY_AS_IS[@]}" )
 LIBS+=( "${OPAL_PBA_LIBS[@]}" )
 
+is_false "$OPAL_PBA_SBWARN" || REQUIRED_PROGS+=( 'od' )
+if [ -n "$OPAL_PBA_TKNPATH" ]; then # AuthToken support
+    REQUIRED_PROGS+=( 'openssl' 'base64' 'dd' 'lsblk' )
+    is_true "$OPAL_PBA_TKNBIND" && REQUIRED_PROGS+=( 'b2sum' )
+    if [ "${OPAL_PBA_TKNKEY:0:4}" == "tpm:" ]; then # TPM2-assisted encryption
+        REQUIRED_PROGS+=( 'systemd-creds' )
+        LIBS+=( /usr/lib/x86_64-linux-gnu/libtss2-*.so* )
+    fi
+fi
+
 # Redirect output
 [[ -n "$OPAL_PBA_OUTPUT_URL" ]] || Error "The OPAL_PBA_OUTPUT_URL configuration variable must be set."
 OUTPUT_URL="$OPAL_PBA_OUTPUT_URL"
