@@ -1,11 +1,11 @@
 
-scheme=$(url_scheme "$BACKUP_URL")
+scheme="$(url_scheme "$BACKUP_URL")"
 case $scheme in
     (nfs)
         PROGS+=(
         showmount
-        mount.$(url_scheme $BACKUP_URL)
-        umount.$(url_scheme $BACKUP_URL)
+        mount.$(url_scheme "$BACKUP_URL")
+        umount.$(url_scheme "$BACKUP_URL")
         )
         ;;
     (*)
