@@ -2,9 +2,9 @@
 # 400_restore_backup.sh
 #
 
-local scheme=$( url_scheme $BACKUP_URL )
-local path=$( url_path $BACKUP_URL )
-local opath=$( backup_path $scheme $path )
+local scheme="$( url_scheme "$BACKUP_URL" )"
+local path="$( url_path "$BACKUP_URL" )"
+local opath="$( backup_path "$scheme" "$path" )"
 
 # Create backup restore log file name:
 local backup_restore_log_dir="$VAR_DIR/restore"
@@ -21,14 +21,12 @@ local backup_restore_log_suffix="restore.log"
 test "$CONFIG_APPEND_FILES" && backup_restore_log_prefix=$backup_restore_log_prefix.$( echo -n $CONFIG_APPEND_FILES | tr -d -c '[:alnum:]/[:space:]' | tr -s '/[:space:]' ':_' )
 local restore_input_basename=""
 
-mkdir -p $BUILD_DIR/outputfs/$NETFS_PREFIX
-
 # The RESTORE_ARCHIVES array contains the restore input files.
 # If it is not set, RESTORE_ARCHIVES is only one element which is the backup archive:
 test "$RESTORE_ARCHIVES" || RESTORE_ARCHIVES=( "$backuparchive" )
 
 # In case of 'tar' the backup restore prog needs to be feed by another program
-# if the backup is splitted and then restore input is not a file but a FIFO
+# if the backup is split and then restore input is not a file but a FIFO
 # i.e. RESTORE_ARCHIVES is then only one element which is the FIFO
 # In this case launch another subshell that runs the feeder program:
 waiting_for_medium_flag_file=$TMP_DIR/waiting_for_restore_medium
@@ -53,8 +51,10 @@ if test -f $TMP_DIR/backup.splitted ; then
             # Wait for the right labelled medium to appear:
             touch $waiting_for_medium_flag_file
             while ! test -f "$backup_file_path" ; do
-                umount "$BUILD_DIR/outputfs"
-                cdrom_drive_names=$( cat /proc/sys/dev/cdrom/info | grep -i "drive name:" | awk '{print $3 " " $4}' )
+                if mountpoint -q "$BUILD_DIR/outputfs" ; then
+                    umount "$BUILD_DIR/outputfs" || LogPrintError "Could not umount what is mounted at $BUILD_DIR/outputfs"
+                fi
+                cdrom_drive_names="$( cat /proc/sys/dev/cdrom/info | grep -i "drive name:" | awk '{print $3 " " $4}' )"
                 ProgressInfo "Insert medium labelled $vol_name (containing $backup_file_name) in a CD-ROM drive ($cdrom_drive_names) ..."
                 sleep 3
                 for cdrom_dev in $cdrom_drive_names ; do
@@ -106,8 +106,8 @@ fi
 # The actual restoring:
 for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
     # Create backup restore log file name (a different one for each restore_input).
-    # Each restore_input is a path like '/tmp/rear.XXXX/outputfs/f121/backup.tar.gz':
-    restore_input_basename=$( basename $restore_input )
+    # Each restore_input is a path like '/var/tmp/rear.XXXX/outputfs/f121/backup.tar.gz':
+    restore_input_basename="$( basename "$restore_input" )"
     backup_restore_log_file=$backup_restore_log_dir/$backup_restore_log_prefix.$restore_input_basename.$MASTER_PID.$backup_restore_log_suffix
     cat /dev/null >$backup_restore_log_file
     LogPrint "Restoring from '$restore_input' (restore log in $backup_restore_log_file) ..."
@@ -133,7 +133,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
     # therefore 'Log ... BACKUP_PROG_CRYPT_KEY ...' is used (and not '$BACKUP_PROG_CRYPT_KEY')
     # but '$BACKUP_PROG_CRYPT_KEY' must be used in the actual command call which means
     # the BACKUP_PROG_CRYPT_KEY value would appear in the log when rear is run in debugscript mode
-    # so that stderr of the confidential command is redirected to /dev/null
+    # so that stderr of the confidential command is redirected to SECRET_OUTPUT_DEV (normally /dev/null)
     # cf. the comment of the UserInput function in lib/_input-output-functions.sh
     # how to keep things confidential when rear is run in debugscript mode
     # because it is more important to not leak out user secrets into a log file
@@ -148,7 +148,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
                 # cf. https://github.com/rear/rear/issues/2369 and https://github.com/rear/rear/issues/2458
                 if is_true "$BACKUP_PROG_CRYPT_ENABLED" ; then 
                     Log "dd if=$restore_input bs=1M | $BACKUP_PROG_DECRYPT_OPTIONS BACKUP_PROG_CRYPT_KEY | $BACKUP_PROG --block-number --totals --verbose ${BACKUP_PROG_OPTIONS[@]} ${BACKUP_PROG_COMPRESS_OPTIONS[@]} -C $TARGET_FS_ROOT/ -x -f -"
-                    dd if=$restore_input bs=1M | { $BACKUP_PROG_DECRYPT_OPTIONS "$BACKUP_PROG_CRYPT_KEY" ; } 2>/dev/null | $BACKUP_PROG --block-number --totals --verbose "${BACKUP_PROG_OPTIONS[@]}" "${BACKUP_PROG_COMPRESS_OPTIONS[@]}" -C $TARGET_FS_ROOT/ -x -f -
+                    dd if=$restore_input bs=1M | { $BACKUP_PROG_DECRYPT_OPTIONS "$BACKUP_PROG_CRYPT_KEY" ; } 2>>/dev/$SECRET_OUTPUT_DEV | $BACKUP_PROG --block-number --totals --verbose "${BACKUP_PROG_OPTIONS[@]}" "${BACKUP_PROG_COMPRESS_OPTIONS[@]}" -C $TARGET_FS_ROOT/ -x -f -
 
                 else
                     Log "dd if=$restore_input bs=1M | $BACKUP_PROG --block-number --totals --verbose ${BACKUP_PROG_OPTIONS[@]} ${BACKUP_PROG_COMPRESS_OPTIONS[@]} -C $TARGET_FS_ROOT/ -x -f -"
@@ -264,7 +264,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
                     restored_KiB_per_second=$(( restored_KiB / restore_seconds ))
                     LogPrint "Restored $restored_MiB MiB in $restore_seconds seconds [avg. $restored_KiB_per_second KiB/sec]"
                 else
-                    # A 'tar -x --totals' stderr messsage should look like 'Total bytes read: 7924664320 (7.4GiB, 95MiB/s)'
+                    # A 'tar -x --totals' stderr message should look like 'Total bytes read: 7924664320 (7.4GiB, 95MiB/s)'
                     # cf. https://www.gnu.org/software/tar/manual/html_section/tar_25.html
                     # in the rear runtime logfile it appears like (without leading blanks):
                     #   3823429+1 records in
