@@ -12,16 +12,16 @@ LogPrint "Restoring system files (YUM_BACKUP_FILES=$YUM_BACKUP_FILES)"
 # see https://github.com/rear/rear/wiki/Coding-Style
 set -e -u -o pipefail
 
-local scheme=$(url_scheme $BACKUP_URL)
-local path=$(url_path $BACKUP_URL)
-local opath=$(backup_path $scheme $path)
+local scheme="$( url_scheme "$BACKUP_URL" )"
+local path="$( url_path "$BACKUP_URL" )"
+local opath="$( backup_path "$scheme" "$path" )"
 
 # The RESTORE_ARCHIVES array contains the restore input files.
 # If it is not set, RESTORE_ARCHIVES is only one element which is the backup archive:
 test "$RESTORE_ARCHIVES" || RESTORE_ARCHIVES=( "$backuparchive" )
 
 # In case of 'tar' the backup restore prog needs to be feed by another program
-# if the backup is splitted and then restore input is not a file but a FIFO
+# if the backup is split and then restore input is not a file but a FIFO
 # i.e. RESTORE_ARCHIVES is then only one element which is the FIFO
 # In this case launch another subshell that runs the feeder program:
 waiting_for_medium_flag_file=$TMP_DIR/waiting_for_restore_medium
@@ -46,7 +46,9 @@ if test -f $TMP_DIR/backup.splitted ; then
             # Wait for the right labelled medium to appear:
             touch $waiting_for_medium_flag_file
             while ! test -f "$backup_file_path" ; do
-                umount "$BUILD_DIR/outputfs"
+                if mountpoint -q "$BUILD_DIR/outputfs" ; then
+                    umount "$BUILD_DIR/outputfs" || LogPrintError "Could not umount what is mounted at $BUILD_DIR/outputfs"
+                fi
                 cdrom_drive_names=$( cat /proc/sys/dev/cdrom/info | grep -i "drive name:" | awk '{print $3 " " $4}' )
                 ProgressInfo "Insert medium labelled $vol_name (containing $backup_file_name) in a CD-ROM drive ($cdrom_drive_names) ..."
                 sleep 3
@@ -126,7 +128,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
                     fi
                 fi
                 if [ -s $TMP_DIR/restore-exclude-list.txt ] ; then
-                    LogPrint "Copying restore exlusion file from $TMP_DIR/restore-exclude-list.txt to $TARGET_FS_ROOT/tmp"
+                    LogPrint "Copying restore exclusion file from $TMP_DIR/restore-exclude-list.txt to $TARGET_FS_ROOT/tmp"
                     cp -a $TMP_DIR/restore-exclude-list.txt $TARGET_FS_ROOT/tmp
                     BACKUP_PROG_OPTIONS+=( --exclude-from=/tmp/restore-exclude-list.txt )
                 fi
@@ -134,7 +136,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
                 # cf. https://github.com/rear/rear/issues/2369 and https://github.com/rear/rear/issues/2458
                 if is_true "$BACKUP_PROG_CRYPT_ENABLED" ; then
                     Log "dd if=$restore_input bs=1M | $BACKUP_PROG_DECRYPT_OPTIONS BACKUP_PROG_CRYPT_KEY | chroot $TARGET_FS_ROOT/ $BACKUP_PROG --acls --preserve-permissions --same-owner --block-number --totals --verbose ${BACKUP_PROG_OPTIONS[@]} ${BACKUP_PROG_COMPRESS_OPTIONS[@]} -C / -x -f -"
-                    dd if=$restore_input bs=1M | { $BACKUP_PROG_DECRYPT_OPTIONS "$BACKUP_PROG_CRYPT_KEY" ; } 2>/dev/null | chroot $TARGET_FS_ROOT/ $BACKUP_PROG --acls --preserve-permissions --same-owner --block-number --totals --verbose "${BACKUP_PROG_OPTIONS[@]}" "${BACKUP_PROG_COMPRESS_OPTIONS[@]}" -C / -x -f -
+                    dd if=$restore_input bs=1M | { $BACKUP_PROG_DECRYPT_OPTIONS "$BACKUP_PROG_CRYPT_KEY" ; } 2>>/dev/$SECRET_OUTPUT_DEV | chroot $TARGET_FS_ROOT/ $BACKUP_PROG --acls --preserve-permissions --same-owner --block-number --totals --verbose "${BACKUP_PROG_OPTIONS[@]}" "${BACKUP_PROG_COMPRESS_OPTIONS[@]}" -C / -x -f -
                 else
                     Log "dd if=$restore_input bs=1M | chroot $TARGET_FS_ROOT/ $BACKUP_PROG --acls --preserve-permissions --same-owner --block-number --totals --verbose ${BACKUP_PROG_OPTIONS[@]} ${BACKUP_PROG_COMPRESS_OPTIONS[@]} -C / -x -f -"
                     dd if=$restore_input bs=1M | chroot $TARGET_FS_ROOT/ $BACKUP_PROG --acls --preserve-permissions --same-owner --block-number --totals --verbose "${BACKUP_PROG_OPTIONS[@]}" "${BACKUP_PROG_COMPRESS_OPTIONS[@]}" -C / -x -f -
@@ -250,7 +252,7 @@ for restore_input in "${RESTORE_ARCHIVES[@]}" ; do
                     restored_KiB_per_second=$(( restored_KiB / restore_seconds ))
                     LogPrint "Restored $restored_MiB MiB in $restore_seconds seconds [avg. $restored_KiB_per_second KiB/sec]"
                 else
-                    # A 'tar -x --totals' stderr messsage should look like 'Total bytes read: 7924664320 (7.4GiB, 95MiB/s)'
+                    # A 'tar -x --totals' stderr message should look like 'Total bytes read: 7924664320 (7.4GiB, 95MiB/s)'
                     # cf. https://www.gnu.org/software/tar/manual/html_section/tar_25.html
                     # in the rear runtime logfile it appears like (without leading blanks):
                     #   3823429+1 records in
